==> libreoffice-7.5.0.3.tar.xz: libreoffice-7.5.0.3/svtools/source/uno/wizard/wizardpagecontroller.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include "wizardpagecontroller.hxx"
#include "wizardshell.hxx"

#include <toolkit/helper/vclunohelper.hxx>
#include <comphelper/diagnose_ex.hxx>


namespace svt::uno
{


    using css::uno::Reference;
    using css::uno::UNO_SET_THROW;
    using css::uno::Exception;
    using css::ui::dialogs::XWizardController;
    using css::awt::XWindow;

    using namespace ::com::sun::star;


    //= WizardPageController


    WizardPageController::WizardPageController(weld::Container* pParent, const Reference< XWizardController >& i_rController,
            const sal_Int16 i_nPageId )
        :m_xController( i_rController )
        ,m_xWizardPage()
    {
        ENSURE_OR_THROW( m_xController.is(), "no controller" );
        try
        {
            // Plug a toplevel SalFrame into the native page which can host our awt widgetry
            m_xWizardPage.set(m_xController->createPage(pParent->CreateChildFrame(), i_nPageId), UNO_SET_THROW);

            Reference< XWindow > xPageWindow(m_xWizardPage->getWindow(), UNO_SET_THROW);
            xPageWindow->setVisible( true );
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }
    }

    WizardPageController::~WizardPageController()
    {
        try
        {
            if ( m_xWizardPage.is() )
                m_xWizardPage->dispose();
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }
    }

    void WizardPageController::initializePage()
    {
        if ( !m_xWizardPage.is() )
            return;

        try
        {
            m_xWizardPage->activatePage();
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }
    }

    bool WizardPageController::commitPage( vcl::WizardTypes::CommitPageReason i_eReason )
    {
        if ( !m_xWizardPage.is() )
            return true;

        try
        {
            return m_xWizardPage->commitPage( WizardShell::convertCommitReasonToTravelType( i_eReason ) );
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }

        return true;
    }

    bool WizardPageController::canAdvance() const
    {
        if ( !m_xWizardPage.is() )
            return true;

        try
        {
            return m_xWizardPage->canAdvance();
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }

        return true;
    }


} // namespace svt::uno


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.5.9~rc1.orig.tar.xz: libreoffice-7.5.9.1/svtools/source/uno/wizard/wizardpagecontroller.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include "wizardpagecontroller.hxx"
#include "wizardshell.hxx"

#include <toolkit/helper/vclunohelper.hxx>
#include <comphelper/diagnose_ex.hxx>


namespace svt::uno
{


    using css::uno::Reference;
    using css::uno::UNO_SET_THROW;
    using css::uno::Exception;
    using css::ui::dialogs::XWizardController;
    using css::awt::XWindow;

    using namespace ::com::sun::star;


    //= WizardPageController


    WizardPageController::WizardPageController(weld::Container* pParent, const Reference< XWizardController >& i_rController,
            const sal_Int16 i_nPageId )
        :m_xController( i_rController )
        ,m_xWizardPage()
    {
        ENSURE_OR_THROW( m_xController.is(), "no controller" );
        try
        {
            // Plug a toplevel SalFrame into the native page which can host our awt widgetry
            css::uno::Reference<css::awt::XWindow> xChildFrame = pParent->CreateChildFrame();
            com::sun::star::awt::Rectangle r0 = xChildFrame->getPosSize();
            m_xWizardPage.set(m_xController->createPage(xChildFrame, i_nPageId), UNO_SET_THROW);

            css::uno::Reference<css::awt::XWindow> xPageWindow(m_xWizardPage->getWindow(), UNO_SET_THROW);

            // If size of page is changed by createPage, then the requested size of the container
            // should also be set to this size, to avoid annoying resizings.
            com::sun::star::awt::Rectangle r1 = xChildFrame->getPosSize();

            if (r0.Width != r1.Width || r0.Height != r1.Height)
                pParent->set_size_request(r1.Width, r1.Height);
            else
            {
                // tdf#132110 If the parent size wasn't overridden, then use
                // the size of the child if that was set
                com::sun::star::awt::Rectangle aChildRect = xPageWindow->getPosSize();
                if (aChildRect.Width && aChildRect.Height)
                    pParent->set_size_request(aChildRect.Width, aChildRect.Height);
            }

            xPageWindow->setVisible(true);
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }
    }

    WizardPageController::~WizardPageController()
    {
        try
        {
            if ( m_xWizardPage.is() )
                m_xWizardPage->dispose();
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }
    }

    void WizardPageController::initializePage()
    {
        if ( !m_xWizardPage.is() )
            return;

        try
        {
            m_xWizardPage->activatePage();
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }
    }

    bool WizardPageController::commitPage( vcl::WizardTypes::CommitPageReason i_eReason )
    {
        if ( !m_xWizardPage.is() )
            return true;

        try
        {
            return m_xWizardPage->commitPage( WizardShell::convertCommitReasonToTravelType( i_eReason ) );
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }

        return true;
    }

    bool WizardPageController::canAdvance() const
    {
        if ( !m_xWizardPage.is() )
            return true;

        try
        {
            return m_xWizardPage->canAdvance();
        }
        catch( const Exception& )
        {
            DBG_UNHANDLED_EXCEPTION("svtools.uno");
        }

        return true;
    }


} // namespace svt::uno


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
